==> jc-1.4.0.tar.gz: soot/toolkits/scalar/IntPair.h <==
// class soot.toolkits.scalar.IntPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ff15b8b70b243cba soot_toolkits_scalar_IntPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_IntPair_H_
#define _JC_soot_toolkits_scalar_IntPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_IntPair$sub_refs	_jc_soot_toolkits_scalar_IntPair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_IntPair$sub_nonrefs	_jc_soot_toolkits_scalar_IntPair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_IntPair$refs	_jc_soot_toolkits_scalar_IntPair$refs;
typedef struct _jc_soot_toolkits_scalar_IntPair$nonrefs	_jc_soot_toolkits_scalar_IntPair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_IntPair$object	_jc_soot_toolkits_scalar_IntPair$object;

typedef const struct _jc_soot_toolkits_scalar_IntPair$vmethods	_jc_soot_toolkits_scalar_IntPair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_IntPair$vtable	_jc_soot_toolkits_scalar_IntPair$vtable;
typedef const struct _jc_soot_toolkits_scalar_IntPair$vtype	_jc_soot_toolkits_scalar_IntPair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_IntPair$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_toolkits_scalar_IntPair$object *, jint, jint);

// Virtual methods structure
struct _jc_soot_toolkits_scalar_IntPair$vmethods {
};

// Vtable
struct _jc_soot_toolkits_scalar_IntPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_IntPair$vmethods	soot_toolkits_scalar_IntPair;
};

// Vtype
struct _jc_soot_toolkits_scalar_IntPair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_IntPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_IntPair$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_IntPair$refs {
    _jc_soot_toolkits_scalar_IntPair$sub_refs	soot_toolkits_scalar_IntPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_IntPair$sub_nonrefs {
	jint	op1;
	jint	op2;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_IntPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_IntPair$sub_nonrefs	soot_toolkits_scalar_IntPair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_IntPair$object {
	_jc_soot_toolkits_scalar_IntPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_IntPair$vtype	*vtype;
	_jc_soot_toolkits_scalar_IntPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_IntPair$vtype _jc_soot_toolkits_scalar_IntPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_IntPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_IntPair$class_object;

#endif	/* _JC_soot_toolkits_scalar_IntPair_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/IntPair.h <==
// class soot.toolkits.scalar.IntPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ff15b8b70b243cba soot_toolkits_scalar_IntPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_IntPair_H_
#define _JC_soot_toolkits_scalar_IntPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_IntPair$sub_refs	_jc_soot_toolkits_scalar_IntPair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_IntPair$sub_nonrefs	_jc_soot_toolkits_scalar_IntPair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_IntPair$refs	_jc_soot_toolkits_scalar_IntPair$refs;
typedef struct _jc_soot_toolkits_scalar_IntPair$nonrefs	_jc_soot_toolkits_scalar_IntPair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_IntPair$object	_jc_soot_toolkits_scalar_IntPair$object;

typedef const struct _jc_soot_toolkits_scalar_IntPair$vmethods	_jc_soot_toolkits_scalar_IntPair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_IntPair$vtable	_jc_soot_toolkits_scalar_IntPair$vtable;
typedef const struct _jc_soot_toolkits_scalar_IntPair$vtype	_jc_soot_toolkits_scalar_IntPair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_IntPair$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_toolkits_scalar_IntPair$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_IntPair$vmethods {
};

// Vtable
struct _jc_soot_toolkits_scalar_IntPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_IntPair$vmethods	soot_toolkits_scalar_IntPair;
};

// Vtype
struct _jc_soot_toolkits_scalar_IntPair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_IntPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_IntPair$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_IntPair$refs {
    _jc_soot_toolkits_scalar_IntPair$sub_refs	soot_toolkits_scalar_IntPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_IntPair$sub_nonrefs {
	jint	op1;
	jint	op2;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_IntPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_IntPair$sub_nonrefs	soot_toolkits_scalar_IntPair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_IntPair$object {
	_jc_soot_toolkits_scalar_IntPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_IntPair$vtype	*vtype;
	_jc_soot_toolkits_scalar_IntPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_IntPair$vtype _jc_soot_toolkits_scalar_IntPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_IntPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_IntPair$class_object;

#endif	/* _JC_soot_toolkits_scalar_IntPair_H_ */
